import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
import { useState } from 'react';
import { useDispatch } from 'react-redux';
import { ActionMenu, Button, IconButton } from "@primer/react";
import { KebabHorizontalIcon, ChevronRightIcon, XIcon, ChevronUpIcon, ChevronDownIcon, SquareIcon } from "@primer/octicons-react";
import { DLA_CELL_HEADER_CLASS } from './base/CellSidebarWidget';
import { notebookActions, selectActiveCell } from '../../NotebookState';
import CellMetadataEditor from '../metadata/CellMetadataEditor';
export const CellSidebarDefault = (props) => {
    const [visible, setVisible] = useState(false);
    const { notebookId, nbgrader } = props;
    const dispatch = useDispatch();
    const activeCell = selectActiveCell(notebookId);
    const layout = (activeCell === null || activeCell === void 0 ? void 0 : activeCell.layout);
    if (layout) {
        const cellWidget = layout.widgets[0];
        if (!visible && ((cellWidget === null || cellWidget === void 0 ? void 0 : cellWidget.node.id) === props.cellId)) {
            setVisible(true);
        }
        if (visible && ((cellWidget === null || cellWidget === void 0 ? void 0 : cellWidget.node.id) !== props.cellId)) {
            setVisible(false);
        }
    }
    if (!visible) {
        return _jsx("div", {}, void 0);
    }
    return (activeCell ?
        _jsxs("div", Object.assign({ className: DLA_CELL_HEADER_CLASS, css: {
                '& p': {
                    marginBottom: '0 !important',
                }
            } }, { children: [_jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: ChevronRightIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.run.started(notebookId));
                        } }, { children: "Run" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertAbove.started({ uid: notebookId, cellType: "code" }));
                        } }, { children: "Code" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertAbove.started({ uid: notebookId, cellType: "markdown" }));
                        } }, { children: "Markdown" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: activeCell.model.type === "code" ?
                        _jsx(Button, Object.assign({ leadingIcon: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                                e.preventDefault();
                                dispatch(notebookActions.changeCellType.started({ uid: notebookId, cellType: "markdown" }));
                            } }, { children: "To Mardown" }), void 0)
                        :
                            _jsx(Button, Object.assign({ leadingIcon: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                                    e.preventDefault();
                                    dispatch(notebookActions.changeCellType.started({ uid: notebookId, cellType: "code" }));
                                } }, { children: "To Code" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "markdown" }));
                        } }, { children: "Markdown" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "code" }));
                        } }, { children: "Code" }), void 0) }), void 0),
                _jsx("span", Object.assign({ style: { display: "flex" } }, { children: _jsx(Button, Object.assign({ leadingIcon: XIcon, variant: "invisible", size: "small", onClick: (e) => {
                            e.preventDefault();
                            dispatch(notebookActions.delete.started(notebookId));
                        } }, { children: "Delete" }), void 0) }), void 0),
                nbgrader &&
                    _jsxs(ActionMenu, { children: [_jsx(ActionMenu.Anchor, { children: _jsx(IconButton, { icon: KebabHorizontalIcon, variant: "invisible", "aria-label": "Open column options" }, void 0) }, void 0),
                            _jsx(ActionMenu.Overlay, { children: _jsx(CellMetadataEditor, { notebookId: notebookId, cell: activeCell, nbgrader: nbgrader }, void 0) }, void 0)] }, void 0)] }), void 0)
        :
            _jsx(_Fragment, {}, void 0));
};
export default CellSidebarDefault;
//# sourceMappingURL=CellSidebarDefault.js.map