import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useDispatch } from "react-redux";
import { createRoot } from 'react-dom/client';
import { Box, Button, ButtonGroup } from '@primer/react';
import Jupyter from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Kernel } from '../jupyter/services/kernel/Kernel';
import Cell from '../components/cell/Cell';
import Notebook from '../components/notebook/Notebook';
import CellSidebarDefault from '../components/notebook/cell/sidebar/CellSidebarDefault';
import Output from "../components/output/Output";
import FileBrowser from "../components/filebrowser/FileBrowser";
import Console from "../components/console/Console";
import Terminal from "../components/terminal/Terminal";
import { selectCell, cellActions } from '../components/cell/CellState';
import { notebookActions } from '../components/notebook/NotebookState';
import NotebookToolbarAdvanced from "./NotebookToolbar";
import CellSidebarNew from '../components/notebook/cell/sidebar/CellSidebarNew';
import "./../../style/index.css";
const SOURCE_1 = '1+1';
const NOTEBOOK_UID_1 = 'notebook-uid-1';
const NOTEBOOK_UID_2 = 'notebook-uid-2';
const NOTEBOOK_UID_3 = 'notebook-uid-3';
const SOURCE_1_OUTPUTS = [
    {
        "data": {
            "text/plain": [
                "2"
            ]
        },
        "execution_count": 1,
        "metadata": {},
        "output_type": "execute_result"
    }
];
const SOURCE_2 = `import ipywidgets as widgets
widgets.IntSlider(
    value=7,
    min=0,
    max=10,
    step=1
 )`;
const CellPreview = () => {
    const cell = selectCell();
    return (_jsxs(_Fragment, { children: [_jsxs(_Fragment, { children: ["source: ", cell.source] }, void 0),
            _jsxs(_Fragment, { children: ["kernel available: ", String(cell.kernelAvailable)] }, void 0)] }, void 0));
};
const CellToolbar = () => {
    const cell = selectCell();
    const dispatch = useDispatch();
    return (_jsxs(_Fragment, { children: [_jsx(Box, Object.assign({ display: "flex" }, { children: _jsxs(ButtonGroup, { children: [_jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(cellActions.execute()) }, { children: "Run the cell" }), void 0),
                        _jsx(Button, Object.assign({ variant: "outline", size: "small", onClick: () => dispatch(cellActions.outputsCount(0)) }, { children: "Reset outputs count" }), void 0)] }, void 0) }), void 0),
            _jsxs(Box, { children: ["Outputs count: ", cell.outputsCount] }, void 0)] }, void 0));
};
const NotebookToolbar = () => {
    const dispatch = useDispatch();
    return (_jsx(Box, Object.assign({ display: "flex" }, { children: _jsxs(ButtonGroup, { children: [_jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(notebookActions.save.started({ uid: NOTEBOOK_UID_1, date: new Date() })) }, { children: "Save the notebook" }), void 0),
                _jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(notebookActions.runAll.started(NOTEBOOK_UID_1)) }, { children: "Run all" }), void 0)] }, void 0) }), void 0));
};
const NotebookKernelChange = () => {
    const { kernelManager } = useJupyter();
    const changeKernel = () => {
        if (kernelManager) {
            const kernel = new Kernel({ kernelManager, kernelName: "pythonqsdf" });
            kernel.getJupyterKernel().then((kernelConnection) => {
            });
        }
    };
    return (_jsxs(_Fragment, { children: [_jsx(Box, Object.assign({ display: "flex" }, { children: _jsx(ButtonGroup, { children: _jsx(Button, Object.assign({ variant: "default", size: "small", onClick: changeKernel }, { children: "Switch Kernel" }), void 0) }, void 0) }), void 0),
            _jsx(Notebook, { path: "test.ipynb", CellSidebar: CellSidebarDefault, uid: NOTEBOOK_UID_2 }, void 0)] }, void 0));
};
const Outputs = () => {
    const { defaultKernel } = useJupyter();
    return (_jsxs(_Fragment, { children: [_jsx(Output, { showEditor: true, autoRun: false, kernel: defaultKernel, code: SOURCE_1, outputs: SOURCE_1_OUTPUTS }, void 0),
            _jsx(Output, { showEditor: true, autoRun: false, kernel: defaultKernel, code: SOURCE_2 }, void 0),
            _jsx(Output, { showEditor: true, autoRun: true, kernel: defaultKernel, code: SOURCE_2 }, void 0)] }, void 0));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsxs(Jupyter, Object.assign({ lite: false, terminals: true }, { children: [_jsx(Console, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(CellPreview, {}, void 0),
        _jsx(CellToolbar, {}, void 0),
        _jsx(Cell, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(Outputs, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(NotebookToolbar, {}, void 0),
        _jsx(Notebook, { path: "test.ipynb", 
            // model={notebookExample as INotebookContent}
            CellSidebar: CellSidebarDefault, uid: NOTEBOOK_UID_1 }, void 0),
        _jsx(Notebook, { path: "test.ipynb", 
            // model={notebookExample1 as INotebookContent}
            CellSidebar: CellSidebarNew, Toolbar: NotebookToolbarAdvanced, 
            // Height - Toolbar Height
            height: 'calc(100vh - 2.6rem)', cellSidebarMargin: 60, uid: NOTEBOOK_UID_3 }, void 0),
        _jsx("hr", {}, void 0),
        _jsx(NotebookKernelChange, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(FileBrowser, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(Terminal, {}, void 0)] }), void 0));
//# sourceMappingURL=JupyterExample.js.map